(********************************************************************************)(**
\file      OVR_CAPI_Audio.pas
\brief     CAPI audio functions.
\copyright Copyright 2015 Oculus VR, LLC. All Rights reserved.
************************************************************************************)
unit OVR_CAPI_Audio;

interface

uses
  Winapi.Windows, OVR_CAPI;

const
  OVR_AUDIO_MAX_DEVICE_STR_SIZE = 128;

type
  TOvrAudioMaxDeviceStr = array[0..OVR_AUDIO_MAX_DEVICE_STR_SIZE-1] of WideChar;

/// Gets the ID of the preferred VR audio output device.
///
/// \param[out] deviceOutId The ID of the user's preferred VR audio device to use, which will be valid upon a successful return value, else it will be WAVE_MAPPER.
///
/// \return Returns an ovrResult indicating success or failure. In the case of failure, use 
///         ovr_GetLastErrorInfo to get more information.
///
function ovr_GetAudioDeviceOutWaveId(out deviceOutId: UINT): TOvrResult;{$IFDEF Win32}cdecl;{$ENDIF}


/// Gets the ID of the preferred VR audio input device.
///
/// \param[out] deviceInId The ID of the user's preferred VR audio device to use, which will be valid upon a successful return value, else it will be WAVE_MAPPER.
///
/// \return Returns an ovrResult indicating success or failure. In the case of failure, use
///         ovr_GetLastErrorInfo to get more information.
///
function ovr_GetAudioDeviceInWaveId(out deviceInId: UINT): TOvrResult;{$IFDEF Win32}cdecl;{$ENDIF}

/// Gets the GUID of the preferred VR audio device as a string.
///
/// \param[out] deviceOutStrBuffer A buffer where the GUID string for the device will copied to.
///
/// \return Returns an ovrResult indicating success or failure. In the case of failure, use 
///         ovr_GetLastErrorInfo to get more information.
///
function ovr_GetAudioDeviceOutGuidStr(out deviceOutStrBuffer: TOvrAudioMaxDeviceStr): TOvrResult;{$IFDEF Win32}cdecl;{$ENDIF}


/// Gets the GUID of the preferred VR audio device.
///
/// \param[out] deviceOutGuid The GUID of the user's preferred VR audio device to use, which will be valid upon a successful return value, else it will be NULL.
///
/// \return Returns an ovrResult indicating success or failure. In the case of failure, use 
///         ovr_GetLastErrorInfo to get more information.
///
function ovr_GetAudioDeviceOutGuid(out deviceOutGuid: TGUID): TOvrResult;{$IFDEF Win32}cdecl;{$ENDIF}


/// Gets the GUID of the preferred VR microphone device as a string.
///
/// \param[out] deviceInStrBuffer A buffer where the GUID string for the device will copied to.
///
/// \return Returns an ovrResult indicating success or failure. In the case of failure, use
///         ovr_GetLastErrorInfo to get more information.
///
function ovr_GetAudioDeviceInGuidStr(out deviceInStrBuffer: TOvrAudioMaxDeviceStr): TOvrResult;{$IFDEF Win32}cdecl;{$ENDIF}


/// Gets the GUID of the preferred VR microphone device.
///
/// \param[out] deviceInGuid The GUID of the user's preferred VR audio device to use, which will be valid upon a successful return value, else it will be NULL.
///
/// \return Returns an ovrResult indicating success or failure. In the case of failure, use
///         ovr_GetLastErrorInfo to get more information.
///
function ovr_GetAudioDeviceInGuid(out deviceInGuid: TGuid): TOvrResult;{$IFDEF Win32}cdecl;{$ENDIF}

implementation

const
  libovrdll = 'libovr.dll';

function ovr_GetAudioDeviceOutWaveId; external libovrdll;
function ovr_GetAudioDeviceInWaveId; external libovrdll;
function ovr_GetAudioDeviceOutGuidStr; external libovrdll;
function ovr_GetAudioDeviceOutGuid; external libovrdll;
function ovr_GetAudioDeviceInGuidStr; external libovrdll;
function ovr_GetAudioDeviceInGuid; external libovrdll;

end.